# aa_configlib.py
# ---------------------------------
# This implements [tag] replacement
# and site key listings, various ways to
# handle configuration issues
# March 25th, 2010 / AA7AS
# ---------------------------------
import re

cfi = '../pos/siteconfig.txt'

def qsafe(string):
	"""This converts quotes to backslash-escaped quotes
	"""
	string = re.sub('"','\\"',string)
	return(re.sub("'","\\'",string))

def rtag(tag,rep,s):		# repl all [tag] with rep in s
	s = re.sub('\['+tag+'\]',rep,s)
	return s

def configure(c,s,x):		# repl all [tag x] in str s with rep from config c
	cv = c[x]
	s = rtag(x,cv,s)
	return s	

def confstring(c,s,default=''):
	try:
		s = str(c[s])
	except:
		s = default
	return s

def confflag(c,s,default=0):
	try:
		s = int(c[s])
	except:
		s = default
	return s

def configall(c,s):			# repl all [*] in str s from config c
	for key,value in c.iteritems():
		s = rtag(key,value,s)
	return s

def getconfig(fn):			# reads site config file into returned cd
	cd = {}
	fh = open(fn)
	ln = 1
	for line in fh:
		c = ''
		line = line.rstrip('\n')
		try:
			a,c = line.split('#',1)
		except: # valid, uncommented, or invalid
			a = line
			c = ''
		if len(a) > 3: # all valid lines are > 3 in size (x=y)
			try:
				key,value = a.split('=',1)
			except: # failed to split on '='
				pass # syntax error
			else:
				value = value.rstrip() # trailing whitespace removed
				value = value.lstrip() # leading whitespace removed
				key = key.rstrip()
				key = key.lstrip()
				cd[key]=value
		ln += 1
	fh.close()
	return cd

def getstdconfig():
	return getconfig(cfi)

def ini(filename,key,default):
	"""Loads a value from 'filename' that is in the form:
key=value
or if this fails, the default value is returned.
First match is returned, others ignored.
	"""
	value = default
	key = key.lower()
	try:
		filehandle = open(filename)
	except:
		pass
	else:
		for line in filehandle:
			try:
				linekey,linevalue = line.split('=',1)
			except:
				pass
			else:
				linekey = linekey.lower()
				if (linekey == key):
					value = linevalue.rstrip('\n')
					try:
						a,b = value.split('#',1)
					except:
						pass
					else:
						value = a.rstrip()
					filehandle.close()
					return value
		filehandle.close()
	return value

def stdini(key,default):
	return ini(cfi,key,default)
