#!/usr/bin/python

# aa_rangebear.py
# ------------------------------------------
# Implements Range and Bearing from lat/long
# April 20th, 2014 / AA7AS
# ------------------------------------------

# degrees = llbear (lat1,lon1,lat2,lon2)		# parms may be string or float
# mi / km = llrange(lat1,lon1,lat2,lon2,mi/km)	# last parm is int

import math

# Range
# arguments |    string or float    | int
# returns a string

def llrange(homelat,homelon,alat,alon,msw):
	ilat = float(alat)
	ilon = float(alon)
	hlat = float(homelat)
	hlon = float(homelon)
	vr = 6371.0
	dlat = math.radians(ilat - hlat)
	dlon = math.radians(ilon - hlon)
	lat1 = math.radians(hlat)
	lat2 = math.radians(ilat)

	va = math.sin(dlat/2.0) * math.sin(dlat/2.0) + math.sin(dlon/2.0) * math.sin(dlon/2.0) * math.cos(lat1) * math.cos(lat2)
	vc = 2.0 * math.atan2(math.sqrt(va),math.sqrt(1.0-va))
	if msw == 1:
		adis = '%.1f' % (vr * vc * 0.621371192237334)
	else:
		adis = '%.1f' % (vr * vc)
	return(adis)

# Bearing
# args are strings or floats
# returns a string

def llbear(homelat,homelon,alat,alon):
	ilat = float(alat)
	ilon = float(alon)
	hlat = float(homelat)
	hlon = float(homelon)
	vr = 6371.0
	dlat = math.radians(ilat - hlat)
	dlon = math.radians(ilon - hlon)
	lat1 = math.radians(hlat)
	lat2 = math.radians(ilat)
	y = math.sin(dlon) * math.cos(lat2)
	x = math.cos(lat1) * math.sin(lat2) - math.sin(lat1) * math.cos(lat2) * math.cos(dlon)
	b = math.degrees(math.atan2(y,x))
	if b < 0: b = 360 + b
	abea = '%.1f' % (b)
	return(abea)

